# Help / Get Help

## Do you like Django Robin?

If you like this project, there is a tiny thing you can do to let us know that we're moving in the right direction.

Simply give django-robin a <a href="https://github.com/linuxgoose/django-robin" target="_blank">star on github</a> <a href="https://github.com/linuxgoose/django-robin" target="_blank">![github star](img/github-star.png)</a>

## Do you want to help us?

Pull requests are always welcome.

You can inspect our docs for typos and spelling mistakes, and create pull requests or <a href="https://github.com/linuxgoose/django-robin/issues" target="_blank">open an issue</a>.

If you have any suggestions to improve **Django Robin**, please create them as <a href="https://github.com/linuxgoose/django-robin/issues" target="_blank">issues</a> on GitHub.


## Do you need help?

Do not hesitate.  Go to <a href="https://github.com/linuxgoose/django-robin/issues" target="_blank">GitHub issues</a> and describe your question or problem.  We'll attempt to address them quickly.